#define RELAY_4 4
#define RELAY_3 5
#include <Wire.h>
#include "Adafruit_NeoPixel.h"
#include <LiquidCrystal_I2C.h>
LiquidCrystal_I2C lcd(0x27, 20, 4);  // set the LCD address to 0x27 for a  20 chars and 4 line display
#include <TroykaMQ.h>
#include <TroykaDHT.h>
#define LED_COUNT 44
#define LED_PIN 6
// создаём объект класса DHT
// передаём номер пина к которому подключён датчик и тип датчика
// типы сенсоров: DHT11, DHT21, DHT22
DHT dht(8, DHT11);
Adafruit_NeoPixel strip = Adafruit_NeoPixel(LED_COUNT, LED_PIN, NEO_GRB + NEO_KHZ800);

// имя для пина, к которому подключен датчик
#define PIN_MQ5 A0
constexpr auto pinSensor = A1;
// имя для пина, к которому подключен нагреватель датчика
#define PIN_MQ5_HEATER 13

// создаём объект для работы с датчиком
// и передаём ему номер пина выходного сигнала и нагревателя
MQ5 mq5(PIN_MQ5, PIN_MQ5_HEATER);

void setup() {

  for (int i = 4; i <= 7; ++i) {
    pinMode(i, OUTPUT);
  }
  strip.begin();
  lcd.init();  // initialize the lcd
  lcd.init();
  // Print a message to the LCD.
  lcd.backlight();

  // открываем последовательный порт
  Serial.begin(9600);
  // включаем нагреватель
  mq5.heaterPwrHigh();
  Serial.println("Heated sensor");
  dht.begin();
  Serial.begin(9600);
}


void loop() {


  for (int i = 0; i < LED_COUNT; i++) {
    strip.setPixelColor(i, strip.Color(199, 21, 133));  // Красный цвет.
  }
  // Передаем цвета ленте.
  strip.show();
  // если прошёл интервал нагрева датчика
  // и калибровка не была совершена
  if (!mq5.isCalibrated() && mq5.heatingCompleted()) {
    // выполняем калибровку датчика на чистом воздухе
    mq5.calibrate();
    // выводим сопротивление датчика в чистом воздухе (Ro) в serial-порт
  }
  // если прошёл интервал нагрева датчика
  // и калибровка была совершена
  if (mq5.isCalibrated() && mq5.heatingCompleted()) {
    // выводим отношения текущего сопротивление датчика
    // к сопротивлению датчика в чистом воздухе (Rs/Ro)
    lcd.setCursor(0, 0);

    lcd.print("Ro: ");
    lcd.println(mq5.getRo());
    lcd.setCursor(0, 1);
    lcd.print("Ratio: ");
    lcd.print(mq5.readRatio());
    // выводим значения газов в ppm
    lcd.setCursor(0, 2);
    lcd.print("LPG: ");
    lcd.print(mq5.readLPG());
    lcd.print(" ppm ");
    lcd.setCursor(0, 3);
    lcd.print(" Methane: ");
    lcd.print(mq5.readMethane());
    lcd.print(" ppm ");
    delay(1000);
  }

  // считывание данных с датчика
  dht.read();
  // проверяем состояние данных
  switch (dht.getState()) {
    // всё OK
    case DHT_OK:
      // выводим показания влажности и температуры
      lcd.setCursor(0, 0);
      lcd.print("TempC: ");
      lcd.print(dht.getTemperatureC());

      lcd.setCursor(0, 1);
      lcd.print("TempK: ");
      lcd.print(dht.getTemperatureK());

      lcd.setCursor(0, 2);
      lcd.print("TempF: ");
      lcd.print(dht.getTemperatureF());

      lcd.setCursor(0, 3);
      lcd.print("Humidity: ");
       Serial.println(dht.getHumidity());
      lcd.print(" %");
      break;
  }
  digitalWrite(RELAY_3, HIGH);
  delay(30000);
  digitalWrite(RELAY_3, LOW);
  delay(5000);

  int valueSensor = analogRead(pinSensor);
  Serial.println(valueSensor);
  if (valueSensor <= 420)
    digitalWrite(RELAY_4, HIGH);
  delay(3000);
  digitalWrite(RELAY_4, LOW);
  delay(5000);
}